/* vim: syn=cpp
 *
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <Arduino.h>

#include "notes.h"
#include "snafucode.h"

#ifndef LOWNOTES
/* Tone pitch table for 16MHz crystal 1:1 divider (130.8Hz [C] ... 4186.0Hz [C]) */
const uint16_t tone_pitch[NTONE_PITCH] PROGMEM = {
	61155, 57722, 54482, 51424, 48538, 45814, 43242, 40815, 38524, 36362 /* ==  220Hz */, 34321, 32395,
	30577, 28860, 27240, 25711, 24268, 22906, 21620, 20407, 19261, 18180 /* ==  440Hz */, 17160, 16197,
	15288, 14429, 13619, 12855, 12133, 11452, 10809, 10203,  9630,  9089 /* ==  880Hz */,  8579,  8098,
	 7643,  7214,  6809,  6427,  6066,  5725,  5404,  5101,  4814,  4544 /* == 1760Hz */,  4289,  4048,
	 3821,  3606,  3404,  3213,  3032,  2862,  2701,  2550,  2406,  2271 /* == 3520Hz */,  2144,  2023,
	 1910,
};

#else

/* Tone pitch table for 16MHz crystal 1:8 divider (16.35Hz [C] ... 4186.0Hz [C]) */
const uint16_t tone_pitch[NTONE_PITCH] PROGMEM = {
	61156, 57724, 54484, 51426, 48540, 45815, 43244, 40817, 38526, 36364 /* == 27.5 */, 34323, 32396,
	30578, 28862, 27242, 25713, 24270, 22908, 21622, 20408, 19263, 18182 /* == 55.0 */, 17161, 16198,
	15289, 14431, 13621, 12856, 12135, 11454, 10811, 10204,  9631,  9091 /* ==  110 */,  8581,  8099,
	 7645,  7215,  6810,  6428,  6067,  5727,  5405,  5102,  4816,  4545 /* ==  220 */,  4290,  4050,
	 3822,  3608,  3405,  3214,  3034,  2863,  2703,  2551,  2408,  2273 /* ==  440 */,  2145,  2025,
	 1911,  1804,  1703,  1607,  1517,  1432,  1351,  1276,  1204,  1136 /* ==  880 */,  1073,  1012,
	  956,   902,   851,   804,   758,   716,   676,   638,   602,   568 /* == 1760 */,   536,   506,
	  478,   451,   426,   402,   379,   358,   338,   319,   301,   284 /* == 3520 */,   268,   253,
	  239,
};
#endif

/* Axel F */
const note_t tune1[] PROGMEM = {
	{NOTE_A3, DUR_1_8},
	{NOTE_P , DUR_1_8},
	{NOTE_C4, DUR_1_8},
	{NOTE_P , DUR_1_16},
	{NOTE_A3, DUR_1_16},
	{NOTE_P , DUR_1_16},
	{NOTE_A3, DUR_1_16},
	{NOTE_D4, DUR_1_8},
	{NOTE_A3, DUR_1_8},
	{NOTE_G3, DUR_1_8},

	{NOTE_A3, DUR_1_8},
	{NOTE_P , DUR_1_8},
	{NOTE_E4, DUR_1_8},
	{NOTE_P , DUR_1_16},
	{NOTE_A3, DUR_1_16},
	{NOTE_P , DUR_1_16},
	{NOTE_A3, DUR_1_16},
	{NOTE_F4, DUR_1_8},
	{NOTE_E4, DUR_1_8},
	{NOTE_C4, DUR_1_8},

	{NOTE_A3, DUR_1_8},
	{NOTE_E4, DUR_1_8},
	{NOTE_A4, DUR_1_8},
	{NOTE_A3, DUR_1_16},
	{NOTE_G3, DUR_1_16},
	{NOTE_P , DUR_1_16},
	{NOTE_G3, DUR_1_16},
	{NOTE_E3, DUR_1_8},
	{NOTE_B3, DUR_1_8},
	{NOTE_A3, DUR_1_4},

	{0, 0},
};

/* Jaws */
const note_t tune2[] PROGMEM = {
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},

	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_C2,  DUR_3_32},
	{NOTE_P ,  DUR_1_32},
	{NOTE_Cs2, DUR_3_32},

	{0, 0},
};

/* Peter Gunn Theme */
const note_t tune3[] PROGMEM = {
	{NOTE_G3,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_G3,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_G3,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_Ds3, DUR_3_16},
	{NOTE_As3, DUR_1_16},
	{NOTE_G3,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_Ds3, DUR_3_16},
	{NOTE_As3, DUR_1_16},
	{NOTE_G3,  DUR_1_4},
	{NOTE_P,   DUR_1_4},

	{NOTE_D4,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_D4,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_D4,  DUR_3_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_Ds4, DUR_3_16},
	{NOTE_As3, DUR_1_16},
	{NOTE_G3,  DUR_1_4},
	{NOTE_Ds3, DUR_3_16},
	{NOTE_As3, DUR_1_16},
	{NOTE_G3,  DUR_1_4},

	{0, 0},
};

/* */
const note_t tune4[] PROGMEM = {
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_D3,  DUR_1_8},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_Ds3, DUR_1_8},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_F3 , DUR_1_8},
	{NOTE_Ds3, DUR_1_16},
	{NOTE_P ,  DUR_1_16},

	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_D3,  DUR_1_8},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_Ds3, DUR_1_8},
	{NOTE_C3,  DUR_1_16},
	{NOTE_P ,  DUR_1_16},
	{NOTE_F3 , DUR_1_8},
	{NOTE_Ds3, DUR_1_16},
	{NOTE_P ,  DUR_1_16},

	{0, 0},
};

/* ... */
const note_t tune5[] PROGMEM = {
	{NOTE_B7,  DUR_1_32},
	{NOTE_A7,  DUR_1_32},
	{NOTE_G7,  DUR_1_32},
	{NOTE_F7,  DUR_1_32},
	{NOTE_E7,  DUR_1_32},
	{NOTE_D7,  DUR_1_32},
	{NOTE_C7,  DUR_1_32},

	{NOTE_B6,  DUR_1_32},
	{NOTE_A6,  DUR_1_32},
	{NOTE_G6,  DUR_1_32},
	{NOTE_F6,  DUR_1_32},
	{NOTE_E6,  DUR_1_32},
	{NOTE_D6,  DUR_1_32},
	{NOTE_C6,  DUR_1_32},

	{NOTE_B5,  DUR_1_32},
	{NOTE_A5,  DUR_1_32},
	{NOTE_G5,  DUR_1_32},
	{NOTE_F5,  DUR_1_32},
	{NOTE_E5,  DUR_1_32},
	{NOTE_D5,  DUR_1_32},
	{NOTE_C5,  DUR_1_32},

	{NOTE_B4,  DUR_1_32},
	{NOTE_A4,  DUR_1_32},
	{NOTE_G4,  DUR_1_32},
	{NOTE_F4,  DUR_1_32},
	{NOTE_E4,  DUR_1_32},
	{NOTE_D4,  DUR_1_32},
	{NOTE_C4,  DUR_1_32},

	{NOTE_B3,  DUR_1_32},
	{NOTE_A3,  DUR_1_32},
	{NOTE_G3,  DUR_1_32},
	{NOTE_F3,  DUR_1_32},
	{NOTE_E3,  DUR_1_32},
	{NOTE_D3,  DUR_1_32},
	{NOTE_C3,  DUR_1_32},

	{NOTE_B2,  DUR_1_32},
	{NOTE_A2,  DUR_1_32},
	{NOTE_G2,  DUR_1_32},
	{NOTE_F2,  DUR_1_32},
	{NOTE_E2,  DUR_1_32},
	{NOTE_D2,  DUR_1_32},
	{NOTE_C2,  DUR_1_32},

	{NOTE_G1,  DUR_1_2},

	{0, 0},
};
