/* vim: syn=cpp
 *
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __ARDUINO_SNAFU_NOTES_H
#define __ARDUINO_SNAFU_NOTES_H

typedef struct __note_t {
	uint8_t		note;
	uint16_t	duration;
} note_t;

#define NTUNES	5

extern const note_t tune1[] PROGMEM;
extern const note_t tune2[] PROGMEM;
extern const note_t tune3[] PROGMEM;
extern const note_t tune4[] PROGMEM;
extern const note_t tune5[] PROGMEM;


#define LOWNOTES	1

#define sound_off()	do { TCCR1A = _BV(COM1A1); /* Set clear output */ } while(0)

/*
 * Frequencies of all notes playable by an Arduino spanning the most used
 * misical range.
 */
#ifndef LOWNOTES
#define NTONE_PITCH	61	/* Number of pitches */
#define NOTEOFFSET	0
#else
#define NTONE_PITCH	97	/* Number of pitches */
#define NOTEOFFSET	36
#endif

extern const uint16_t tone_pitch[NTONE_PITCH] PROGMEM;

/* These are offset+1 into the pitch table */
/* Note 0 (zero) is a pause */

#define NOTE_PAUSE	0
#define NOTE_P		NOTE_PAUSE

#ifdef LOWNOTES
#define NOTE_C0		1
#define NOTE_Cs0	2
#define NOTE_Df0	NOTE_Cs0
#define NOTE_D0		3
#define NOTE_Ds0	4
#define NOTE_Ef0	NOTE_Ds0
#define NOTE_E0		5
#define NOTE_F0		6
#define NOTE_Fs0	7
#define NOTE_Gf0	NOTE_Fs0
#define NOTE_G0		8
#define NOTE_Gs0	9
#define NOTE_Af0	NOTE_Gs0
#define NOTE_A0		10
#define NOTE_As0	11
#define NOTE_Bf0	NOTE_As0
#define NOTE_B0		12
#define NOTE_C1		13
#define NOTE_Cs1	14
#define NOTE_Df1	NOTE_Cs1
#define NOTE_D1		15
#define NOTE_Ds1	16
#define NOTE_Ef1	NOTE_Ds1
#define NOTE_E1		17
#define NOTE_F1		18
#define NOTE_Fs1	19
#define NOTE_Gf1	NOTE_Fs1
#define NOTE_G1		20
#define NOTE_Gs1	21
#define NOTE_Af1	NOTE_Gs1
#define NOTE_A1		22		/* This should be 55Hz */
#define NOTE_As1	23
#define NOTE_Bf1	NOTE_As1
#define NOTE_B1		24
#define NOTE_C2		25
#define NOTE_Cs2	26
#define NOTE_Df2	NOTE_Cs2
#define NOTE_D2		27
#define NOTE_Ds2	28
#define NOTE_Ef2	NOTE_Ds2
#define NOTE_E2		29
#define NOTE_F2		30
#define NOTE_Fs2	31
#define NOTE_Gf2	NOTE_Fs2
#define NOTE_G2		32
#define NOTE_Gs2	33
#define NOTE_Af2	NOTE_Gs2
#define NOTE_A2		34
#define NOTE_As2	35
#define NOTE_Bf2	NOTE_As2
#define NOTE_B2		36
#endif

#define NOTE_C3		(NOTEOFFSET + 1)
#define NOTE_Cs3	(NOTEOFFSET + 2)
#define NOTE_Df3	NOTE_Cs3
#define NOTE_D3		(NOTEOFFSET + 3)
#define NOTE_Ds3	(NOTEOFFSET + 4)
#define NOTE_Ef3	NOTE_Ds3
#define NOTE_E3		(NOTEOFFSET + 5)
#define NOTE_F3		(NOTEOFFSET + 6)
#define NOTE_Fs3	(NOTEOFFSET + 7)
#define NOTE_Gf3	NOTE_Fs3
#define NOTE_G3		(NOTEOFFSET + 8)
#define NOTE_Gs3	(NOTEOFFSET + 9)
#define NOTE_Af3	NOTE_Gs3
#define NOTE_A3		(NOTEOFFSET + 10)
#define NOTE_As3	(NOTEOFFSET + 11)
#define NOTE_Bf3	NOTE_As3
#define NOTE_B3		(NOTEOFFSET + 12)
#define NOTE_C4		(NOTEOFFSET + 13)
#define NOTE_Cs4	(NOTEOFFSET + 14)
#define NOTE_Df4	NOTE_Cs4
#define NOTE_D4		(NOTEOFFSET + 15)
#define NOTE_Ds4	(NOTEOFFSET + 16)
#define NOTE_Ef4	NOTE_Ds4
#define NOTE_E4		(NOTEOFFSET + 17)
#define NOTE_F4		(NOTEOFFSET + 18)
#define NOTE_Fs4	(NOTEOFFSET + 19)
#define NOTE_Gf4	NOTE_Fs4
#define NOTE_G4		(NOTEOFFSET + 20)
#define NOTE_Gs4	(NOTEOFFSET + 21)
#define NOTE_Af4	NOTE_Gs4
#define NOTE_A4		(NOTEOFFSET + 22)	/* This should be 440Hz */
#define NOTE_As4	(NOTEOFFSET + 23)
#define NOTE_Bf4	NOTE_As4
#define NOTE_B4		(NOTEOFFSET + 24)
#define NOTE_C5		(NOTEOFFSET + 25)
#define NOTE_Cs5	(NOTEOFFSET + 26)
#define NOTE_Df5	NOTE_Cs5
#define NOTE_D5		(NOTEOFFSET + 27)
#define NOTE_Ds5	(NOTEOFFSET + 28)
#define NOTE_Ef5	NOTE_Ds5
#define NOTE_E5		(NOTEOFFSET + 29)
#define NOTE_F5		(NOTEOFFSET + 30)
#define NOTE_Fs5	(NOTEOFFSET + 31)
#define NOTE_Gf5	NOTE_Fs5
#define NOTE_G5		(NOTEOFFSET + 32)
#define NOTE_Gs5	(NOTEOFFSET + 33)
#define NOTE_Af5	NOTE_Gs5
#define NOTE_A5		(NOTEOFFSET + 34)
#define NOTE_As5	(NOTEOFFSET + 35)
#define NOTE_Bf5	NOTE_As5
#define NOTE_B5		(NOTEOFFSET + 36)
#define NOTE_C6		(NOTEOFFSET + 37)
#define NOTE_Cs6	(NOTEOFFSET + 38)
#define NOTE_Df6	NOTE_Cs6
#define NOTE_D6		(NOTEOFFSET + 39)
#define NOTE_Ds6	(NOTEOFFSET + 40)
#define NOTE_Ef6	NOTE_Ds6
#define NOTE_E6		(NOTEOFFSET + 41)
#define NOTE_F6		(NOTEOFFSET + 42)
#define NOTE_Fs6	(NOTEOFFSET + 43)
#define NOTE_Gf6	NOTE_Fs6
#define NOTE_G6		(NOTEOFFSET + 44)
#define NOTE_Gs6	(NOTEOFFSET + 45)
#define NOTE_Af6	NOTE_Gs6
#define NOTE_A6		(NOTEOFFSET + 46)
#define NOTE_As6	(NOTEOFFSET + 47)
#define NOTE_Bf6	NOTE_As6
#define NOTE_B6		(NOTEOFFSET + 48)
#define NOTE_C7		(NOTEOFFSET + 49)
#define NOTE_Cs7	(NOTEOFFSET + 50)
#define NOTE_Df7	NOTE_Cs7
#define NOTE_D7		(NOTEOFFSET + 51)
#define NOTE_Ds7	(NOTEOFFSET + 52)
#define NOTE_Ef7	NOTE_Ds7
#define NOTE_E7		(NOTEOFFSET + 53)
#define NOTE_F7		(NOTEOFFSET + 54)
#define NOTE_Fs7	(NOTEOFFSET + 55)
#define NOTE_Gf7	NOTE_Fs7
#define NOTE_G7		(NOTEOFFSET + 56)
#define NOTE_Gs7	(NOTEOFFSET + 57)
#define NOTE_Af7	NOTE_Gs7
#define NOTE_A7		(NOTEOFFSET + 58)
#define NOTE_As7	(NOTEOFFSET + 59)
#define NOTE_Bf7	NOTE_As7
#define NOTE_B7		(NOTEOFFSET + 60)
#define NOTE_C8		(NOTEOFFSET + 61)

/* Duration in ms at 120 BPM */
#define DUR_1_1		2000
#define DUR_1_2		1000
#define DUR_2_2		DUR_1_1
#define DUR_1_4		500
#define DUR_2_4		DUR_1_2
#define DUR_3_4		1500
#define DUR_4_4		DUR_2_2
#define DUR_1_8		250
#define DUR_2_8		DUR_1_4
#define DUR_3_8		750
#define DUR_4_8		DUR_2_4
#define DUR_5_8		1250
#define DUR_6_8		DUR_3_4
#define DUR_7_8		1750
#define DUR_8_8		DUR_4_4
#define DUR_1_16	125
#define DUR_2_16	DUR_1_8
#define DUR_3_16	375
#define DUR_4_16	DUR_2_8
#define DUR_5_16	625
#define DUR_6_16	DUR_3_8
#define DUR_7_16	875
#define DUR_8_16	DUR_4_8
#define DUR_9_16	1125
#define DUR_10_16	DUR_5_8
#define DUR_11_16	1375
#define DUR_12_16	DUR_6_8
#define DUR_13_16	1625
#define DUR_14_16	DUR_7_8
#define DUR_15_16	1875
#define DUR_16_16	DUR_8_8
#define DUR_1_32	63
#define DUR_2_32	DUR_1_16
#define DUR_3_32	188
#define DUR_4_32	DUR_2_16
#define DUR_5_32	313
#define DUR_6_32	DUR_3_16
#define DUR_7_32	438
#define DUR_8_32	DUR_4_16
#define DUR_9_32	563
#define DUR_10_32	DUR_5_16
#define DUR_11_32	688
#define DUR_12_32	DUR_6_16
#define DUR_13_32	813
#define DUR_14_32	DUR_7_16
#define DUR_15_32	938
#define DUR_16_32	DUR_8_16
#define DUR_17_32	1063
#define DUR_18_32	DUR_9_16
#define DUR_19_32	1188
#define DUR_20_32	DUR_10_16
#define DUR_21_32	1313
#define DUR_22_32	DUR_11_16
#define DUR_23_32	1438
#define DUR_24_32	DUR_12_16
#define DUR_25_32	1563
#define DUR_26_32	DUR_13_16
#define DUR_27_32	1688
#define DUR_28_32	DUR_14_16
#define DUR_29_32	1813
#define DUR_30_32	DUR_15_16
#define DUR_31_32	1938
#define DUR_32_32	DUR_16_16

#endif
