/*
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <Arduino.h>

#include "serial.h"
#include "snafucode.h"
#include "timing.h"

static void serial_print_timing(const timing_t *t)
{
	Serial.print(F("  Timestamp     : "));
	Serial.println(t->tm.timestamp);
	Serial.print(F("  Events        : "));
	Serial.println(t->tm.events);
	Serial.print(F("  mo we da ho mi: "));
	Serial.print(t->months);
	Serial.write(' ');
	Serial.print(t->weeks);
	Serial.write(' ');
	Serial.print(t->days);
	Serial.write(' ');
	Serial.print(t->hours);
	Serial.write(' ');
	Serial.println(t->minutes);
}

void serial_status(void)
{
	Serial.print(F("Current Timestamp: "));
	Serial.println(currentstamp);

	Serial.println(F("SNAFU:"));
	serial_print_timing(&time_sn);
	Serial.println(F("Arrrgh!:"));
	serial_print_timing(&time_ar);
	Serial.println(F("Brainfart:"));
	serial_print_timing(&time_bf);
}

void serial_menu(void)
{
	Serial.println(F("[sS]      - de-/in-crease snafu events"));
	Serial.println(F("[aA]      - de-/in-crease arrrgh events"));
	Serial.println(F("[bB]      - de-/in-crease brainfart events"));
	Serial.println(F("[r][sab]  - reset time"));
	Serial.println(F("[hH][sab] - de-/in-crease hours"));
	Serial.println(F("[dD][sab] - de-/in-crease days"));
	Serial.println(F("[.]       - current status"));
	Serial.print(F("input> "));
}

void serial_input(void)
{
	static uint8_t serstate;
	static uint8_t updown;

	while(Serial.available() > 0) {
		uint8_t ch = Serial.read();
		lfsr_prng_mix(ch);
		switch(serstate) {
		default:
			serstate = 0;
			switch(ch) {
			case 's':
				if(time_sn.tm.events) {
					time_sn.tm.events--;
					timing_save(&time_sn.tm, IDX_SN);
				}
				break;
			case 'S':
				if(time_sn.tm.events < MAXCOUNT) {
					time_sn.tm.events++;
					timing_save(&time_sn.tm, IDX_SN);
				}
				break;
			case 'a':
				if(time_ar.tm.events) {
					time_ar.tm.events--;
					timing_save(&time_ar.tm, IDX_AR);
				}
				break;
			case 'A':
				if(time_ar.tm.events < MAXCOUNT) {
					time_ar.tm.events++;
					timing_save(&time_ar.tm, IDX_AR);
				}
				break;
			case 'b':
				if(time_bf.tm.events) {
					time_bf.tm.events--;
					timing_save(&time_bf.tm, IDX_BF);
				}
				break;
			case 'B':
				if(time_bf.tm.events < MAXCOUNT) {
					time_bf.tm.events++;
					timing_save(&time_bf.tm, IDX_BF);
				}
				break;
			case '.':
				serial_status();
				break;
			case 'r':
			case 'R':
				serstate = 1;
				break;
			case 'h':
			case 'H':
				updown = ch == 'H';
				serstate = 2;
				break;
			case 'd':
			case 'D':
				updown = ch == 'D';
				serstate = 3;
				break;
			case '\n':
			case '\r':
			case '\t':
				break;
			default:
				serial_menu();
				break;
			}
			break;
		case 1:
			serstate = 0;
			switch(ch) {
			case 's':
			case 'S':
				timing_reset(IDX_SN);
				break;
			case 'a':
			case 'A':
				timing_reset(IDX_AR);
				break;
			case 'b':
			case 'B':
				timing_reset(IDX_BF);
				break;
			}
			break;
		case 2:
			serstate = 0;
			switch(ch) {
			case 's':
			case 'S':
				time_sn.tm.timestamp += (updown ? 3600ul : -3600ul);
				timing_save(&time_sn.tm, IDX_SN);
				timing_update(IDX_SN);
				break;
			case 'a':
			case 'A':
				time_ar.tm.timestamp += (updown ? 3600ul : -3600ul);
				timing_save(&time_ar.tm, IDX_AR);
				timing_update(IDX_AR);
				break;
			case 'b':
			case 'B':
				time_bf.tm.timestamp += (updown ? 3600ul : -3600ul);
				timing_save(&time_bf.tm, IDX_BF);
				timing_update(IDX_BF);
				break;
			}
			break;
		case 3:
			serstate = 0;
			switch(ch) {
			case 's':
			case 'S':
				time_sn.tm.timestamp += (updown ? 86400ul : -86400ul);
				timing_save(&time_sn.tm, IDX_SN);
				timing_update(IDX_SN);
				break;
			case 'a':
			case 'A':
				time_ar.tm.timestamp += (updown ? 86400ul : -86400ul);
				timing_save(&time_ar.tm, IDX_AR);
				timing_update(IDX_AR);
				break;
			case 'b':
			case 'B':
				time_bf.tm.timestamp += (updown ? 86400ul : -86400ul);
				timing_save(&time_bf.tm, IDX_BF);
				timing_update(IDX_BF);
				break;
			}
			break;
		}
	}
}
