/* vim: syn=cpp
 *
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __ARDUINO_SNAFU_SNAFUCODE_H
#define __ARDUINO_SNAFU_SNAFUCODE_H

#include <stdint.h>

#define NELEM(x)		(sizeof(x) / sizeof((x)[0]))

//#define COUNT_DEC	1
#define COUNT_HEX	1

#if !defined(COUNT_DEC) && !defined(COUNT_HEX)
#define COUNT_DEC	1
#elif defined(COUNT_DEC) && defined(COUNT_HEX)
# undef COUNT_HEX
#endif

#ifdef COUNT_DEC
#define MAXCOUNT	9999
#else
#define MAXCOUNT	0xffff
#endif

typedef enum {
	MLED_SN = 0,
	MLED_AR = 1,
	MLED_BF = 2,
} mledset_t;

typedef union __backbuf_t {
	struct {
		uint8_t	r1;	// Word lights
		uint8_t	g1;
		uint8_t	b1;
		uint8_t	r2;
		uint8_t	g2;
		uint8_t	b2;
		uint8_t	r3;
		uint8_t	g3;
		uint8_t	b3;
		uint8_t	m1;	// Matrix
		uint8_t	m2;
		uint8_t	m3;
	};
	uint8_t data[12];
} backbuf_t;

/* Logical color of a word */
typedef struct __wordclr_t {
	uint16_t	r : 3;
	uint16_t	g : 3;
	uint16_t	b : 3;
	uint16_t	reserved : 7;
} wordclr_t;

/* Logical colors of entire screen */
typedef struct __words_t {
	union {
		struct {
			wordclr_t	zero;
			wordclr_t	one;
			wordclr_t	two;
			wordclr_t	three;
			wordclr_t	four;
			wordclr_t	five;
			wordclr_t	six;
			wordclr_t	seven;
			wordclr_t	eight;
			wordclr_t	nine;
		};
		wordclr_t	digits[10];
	};
	wordclr_t	ten;
	wordclr_t	twenty;
	wordclr_t	thirty;
	wordclr_t	forty;
	wordclr_t	fifty;
	wordclr_t	minutes;
	wordclr_t	hours;
	wordclr_t	days;
	wordclr_t	weeks;
	wordclr_t	months;
	wordclr_t	last;
	wordclr_t	snafu;
	wordclr_t	arrrgh;
	wordclr_t	brainfart;
} words_t;


extern uint32_t currentstamp;		// in Unix epoch
uint8_t lfsr_prng(void);
void lfsr_prng_mix(uint16_t v);

#endif
