/*
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <Arduino.h>

#include "snafucode.h"
#include "timing.h"
#include "RTClib.h"

extern RTC_DS1307 rtc;			// Our clock chip

#define MAGIC_MARKER	0x31415926

void timing_save(time_memory_t *tmp, uint8_t idx)
{
	rtc.writenvram(idx * sizeof(*tmp), (uint8_t *)tmp, sizeof(*tmp));
}

static inline void timing_read(time_memory_t *tmp, uint8_t idx)
{
	rtc.readnvram((uint8_t *)tmp, sizeof(*tmp), idx * sizeof(*tmp));
}

void timing_saveall(void)
{
	timing_save(&time_sn.tm, IDX_SN);
	timing_save(&time_ar.tm, IDX_AR);
	timing_save(&time_bf.tm, IDX_BF);
}

void timing_update(uint8_t idx)
{
	uint32_t delta = (currentstamp - time_xx[idx].tm.timestamp) / 60;
	time_xx[idx].minutes = delta % 60;
	delta /= 60;
	time_xx[idx].hours   = delta % 24;
	delta /= 24;
	time_xx[idx].days    = delta;
	time_xx[idx].weeks   = delta / 7;
	time_xx[idx].months  = delta / 30;	// Yeah, almost right...
}

void timing_readall(void)
{
	timing_read(&time_sn.tm, IDX_SN);
	timing_read(&time_ar.tm, IDX_AR);
	timing_read(&time_bf.tm, IDX_BF);
	if(time_sn.tm.magic != MAGIC_MARKER || !time_sn.tm.timestamp || time_sn.tm.timestamp > currentstamp) {
		time_sn.tm.magic = MAGIC_MARKER;
		time_sn.tm.events = 0;
		time_sn.tm.timestamp = currentstamp;
		timing_save(&time_sn.tm, IDX_SN);
	}
	if(time_ar.tm.magic != MAGIC_MARKER || !time_ar.tm.timestamp || time_ar.tm.timestamp > currentstamp) {
		time_ar.tm.magic = MAGIC_MARKER;
		time_ar.tm.events = 0;
		time_ar.tm.timestamp = currentstamp;
		timing_save(&time_ar.tm, IDX_AR);
	}
	if(time_bf.tm.magic != MAGIC_MARKER || !time_bf.tm.timestamp || time_bf.tm.timestamp > currentstamp) {
		time_bf.tm.magic = MAGIC_MARKER;
		time_bf.tm.events = 0;
		time_bf.tm.timestamp = currentstamp;
		timing_save(&time_bf.tm, IDX_BF);
	}
	timing_update(IDX_SN);
	timing_update(IDX_AR);
	timing_update(IDX_BF);
}

void timing_reset(uint8_t idx)
{
	time_xx[idx].tm.timestamp = currentstamp;
	timing_save(&time_xx[idx].tm, idx);
	timing_update(idx);
}

