/*
 * SNAFU - Letting go of daily frustration
 *
 * Copyright (C) 2016  B.Stultiens
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __SNAFUCODE_TIMING_H
#define __SNAFUCODE_TIMING_H

// Representation in RTC memory
typedef struct __time_memory_t {
	uint32_t	magic;		// To ensure validity
	uint32_t	timestamp;	// Unix timestamp of last event
	uint16_t	events;		// Pushes of a button
} time_memory_t;

typedef struct __timing_t {
	time_memory_t	tm;
	uint8_t 	minutes;	// Calculated offset "since last" event
	uint8_t 	hours;		// Minutes, hours are relative (modulo) values
	uint16_t 	days;		// Days, weeks, months are absolute numbers
	uint16_t	weeks;
	uint16_t 	months;
} timing_t;

void timing_save(time_memory_t *tmp, uint8_t idx);
void timing_saveall(void);
void timing_update(uint8_t idx);
void timing_readall(void);
void timing_reset(uint8_t idx);

#define IDX_SN	MLED_SN
#define IDX_AR	MLED_AR
#define IDX_BF	MLED_BF

extern timing_t time_xx[3];

#define time_sn (time_xx[IDX_SN])
#define time_ar (time_xx[IDX_AR])
#define time_bf (time_xx[IDX_BF])

#endif
